@@ -11,14 +11,15 @@ end
 describe Sequel::Dataset::Pagination, 'extension' do
   
   class Car < Sequel::Model
+    self.dataset = dataset.extension(:pagination)
   end
 
   it "should have the #paginate method" do
-    Car.should respond_to(:paginate)
+    Car.dataset.should respond_to(:paginate)
   end
 
   it "should NOT have the #paginate_by_sql method" do
-    Car.should_not respond_to(:paginate_by_sql)
+    Car.dataset.should_not respond_to(:paginate_by_sql)
   end
 
   describe 'pagination' do
@@ -29,7 +30,7 @@ describe Sequel::Dataset::Pagination, 'extension' do
     end
 
     it "should imitate WillPaginate::Collection" do
-      result = Car.paginate(1, 2)
+      result = Car.dataset.paginate(1, 2)
       
       result.should_not be_empty
       result.size.should == 2
@@ -41,16 +42,16 @@ describe Sequel::Dataset::Pagination, 'extension' do
     end
     
     it "should perform" do
-      Car.paginate(1, 2).all.should == [Car[1], Car[2]]
+      Car.dataset.paginate(1, 2).all.should == [Car[1], Car[2]]
     end
 
     it "should be empty" do
-      result = Car.paginate(3, 2)
+      result = Car.dataset.paginate(3, 2)
       result.should be_empty
     end
     
     it "should perform with #select and #order" do
-      result = Car.select("name as foo".lit).order(:name).paginate(1, 2).all
+      result = Car.select(Sequel.lit("name as foo")).order(:name).paginate(1, 2).all
       result.size.should == 2
       result.first.values[:foo].should == "Aston Martin"
     end
