@@ -14,7 +14,8 @@ Routes.draw do
   get 'ibocorp(/:page)' => 'ibocorp#index',
         :constraints => { :page => /\d+/ }, :defaults => { :page => 1 }
 
-  get ':controller(/:action(/:id(.:format)))'
+  get 'foo/bar' => 'foo#bar'
+  get 'baz/list' => 'baz#list'
 end
 
 describe WillPaginate::ActionView do
@@ -38,7 +39,14 @@ describe WillPaginate::ActionView do
   attr_reader :assigns, :controller, :request
   
   def render(locals)
-    @view = ActionView::Base.new([], @assigns, @controller)
+    lookup_context = []
+    if defined? ActionView::LookupContext
+      lookup_context = ActionView::LookupContext.new(lookup_context)
+    end
+
+    klass = ActionView::Base
+    klass = klass.with_empty_template_cache if klass.respond_to?(:with_empty_template_cache)
+    @view = klass.new(lookup_context, @assigns, @controller)
     @view.request = @request
     @view.singleton_class.send(:include, @controller._routes.url_helpers)
     @view.render(:inline => @template, :locals => locals)
@@ -120,16 +128,20 @@ describe WillPaginate::ActionView do
   it "should match expected markup" do
     paginate
     expected = <<-HTML
-      <div class="pagination"><span class="previous_page disabled">&#8592; Previous</span>
-      <em class="current">1</em>
-      <a href="/foo/bar?page=2" rel="next">2</a>
-      <a href="/foo/bar?page=3">3</a>
+      <div class="pagination" role="navigation" aria-label="Pagination"><span class="previous_page disabled">&#8592; Previous</span>
+      <em class="current" aria-label="Page 1" aria-current="page">1</em>
+      <a href="/foo/bar?page=2" aria-label="Page 2" rel="next">2</a>
+      <a href="/foo/bar?page=3" aria-label="Page 3">3</a>
       <a href="/foo/bar?page=2" class="next_page" rel="next">Next &#8594;</a></div>
     HTML
     expected.strip!.gsub!(/\s{2,}/, ' ')
-    expected_dom = parse_html_document(expected).root
+    expected_dom = parse_html_document(expected)
 
-    html_document.root.should == expected_dom
+    if expected_dom.respond_to?(:canonicalize)
+      html_document.canonicalize.should == expected_dom.canonicalize
+    else
+      html_document.root.should == expected_dom.root
+    end
   end
   
   it "should output escaped URLs" do
